@@ -1,4 +1,4 @@
-/* $Id: tftp.c,v 1.11 2001/11/13 04:16:12 hpa Exp $ */
+/* $Id: tftp.c,v 1.12 2001/11/13 19:58:32 hpa Exp $ */
 
 /* $OpenBSD: tftp.c,v 1.4 1997/08/06 06:43:45 deraadt Exp $	*/
 /* $NetBSD: tftp.c,v 1.5 1995/04/29 05:55:25 cgd Exp $	*/
@@ -42,7 +42,7 @@
 /* static char sccsid[] = "@(#)tftp.c	8.1 (Berkeley) 6/6/93"; */
 /* static char rcsid[] = "$OpenBSD: tftp.c,v 1.4 1997/08/06 06:43:45 deraadt Exp $"; */
 static const char *rcsid UNUSED =
-"tftp-hpa $Id: tftp.c,v 1.11 2001/11/13 04:16:12 hpa Exp $";
+"tftp-hpa $Id: tftp.c,v 1.12 2001/11/13 19:58:32 hpa Exp $";
 #endif /* not lint */
 
 /* Many bug fixes are from Jim Guyton <guyton@rand-unix> */
@@ -74,13 +74,6 @@ extern  int     verbose;
 extern  int     rexmtval;
 extern  int     maxtimeout;
 
-#ifndef EOPTNEG
-#define EOPTNEG	8
-#endif
-#ifndef OACK
-#define OACK	6
-#endif
-
 #define PKTSIZE    SEGSIZE+4
 char    ackbuf[PKTSIZE];
 int	timeout;
