@@ -1,4 +1,4 @@
-/* tftp-hpa: $Id: tftpd.c,v 1.35 2001/11/13 04:16:12 hpa Exp $ */
+/* tftp-hpa: $Id: tftpd.c,v 1.38 2001/11/15 04:11:39 hpa Exp $ */
 
 /* $OpenBSD: tftpd.c,v 1.13 1999/06/23 17:01:36 deraadt Exp $	*/
 
@@ -45,7 +45,7 @@ static const char *copyright UNUSED =
 /*static char sccsid[] = "from: @(#)tftpd.c	5.13 (Berkeley) 2/26/91";*/
 /*static char rcsid[] = "$OpenBSD: tftpd.c,v 1.13 1999/06/23 17:01:36 deraadt Exp $: tftpd.c,v 1.6 1997/02/16 23:49:21 deraadt Exp $";*/
 static const char *rcsid UNUSED =
-"tftp-hpa $Id: tftpd.c,v 1.35 2001/11/13 04:16:12 hpa Exp $";
+"tftp-hpa $Id: tftpd.c,v 1.38 2001/11/15 04:11:39 hpa Exp $";
 #endif /* not lint */
 
 /*
@@ -98,13 +98,6 @@ struct request_info wrap_request;
 #define TRIES   4		/* Number of attempts to send each packet */
 #define TIMEOUT_LIMIT (TRIES*(TRIES+1)/2)
 
-#ifndef OACK
-#define OACK	6
-#endif
-#ifndef EOPTNEG
-#define EOPTNEG	8
-#endif
-
 char   *__progname;
 int	peer;
 int	timeout    = TIMEOUT;
@@ -221,7 +214,7 @@ main(int argc, char **argv)
   
   openlog(__progname, LOG_PID|LOG_NDELAY, LOG_DAEMON);
   
-  while ((c = getopt(argc, argv, "csvla:u:r:t:m:")) != -1)
+  while ((c = getopt(argc, argv, "csvVla:u:r:t:m:")) != -1)
     switch (c) {
     case 'c':
       cancreate = 1;
@@ -265,6 +258,11 @@ main(int argc, char **argv)
     case 'v':
       verbosity++;
       break;
+    case 'V':
+      /* Print configuration to stdout and exit */
+      printf("%s\n", TFTPD_CONFIG_STR);
+      exit(0);
+      break;
     default:
       usage();
       break;
@@ -1100,7 +1098,7 @@ tftp_recvfile(struct formats *pf, struct tftphdr *oap, int oacklen)
   ap->th_block = htons((u_short)(block));
   (void) send(peer, ackbuf, 4, 0);
   
-  set_signal(SIGALRM, justquit, SA_RESETHAND); /* just quit on timeout */
+  set_signal(SIGALRM, justquit, 0); /* just quit on timeout */
   alarm(rexmtval);
   n = recv(peer, buf, sizeof (buf), 0); /* normally times out and quits */
   alarm(0);
